@@ -21,8 +21,10 @@ class APISpecHandler(web.StaticFileHandler, IPythonHandler):
     @web.authenticated
     def get(self):
         self.log.warning("Serving api spec (experimental, incomplete)")
-        self.set_header('Content-Type', 'text/x-yaml')
         return web.StaticFileHandler.get(self, 'api.yaml')
+        
+    def get_content_type(self):
+        return 'text/x-yaml'
 
 class APIStatusHandler(APIHandler):
 
