@@ -100,7 +100,7 @@ def find_package_data():
     """
     Find package_data.
     """
-    # This is not enough for these things to appear in an sdist.
+    # This is not enough for these things to appear in a sdist.
     # We need to muck with the MANIFEST to get this to work
     
     # exclude components and less from the walk;
@@ -133,7 +133,7 @@ def find_package_data():
     # (there are lots of resources we bundle for sdist-reasons that we don't actually use)
     static_data.extend([
         pjoin(components, "backbone", "backbone-min.js"),
-        pjoin(components, "bootstrap", "js", "bootstrap.min.js"),
+        pjoin(components, "bootstrap", "dist", "js", "bootstrap.min.js"),
         pjoin(components, "bootstrap-tour", "build", "css", "bootstrap-tour.min.css"),
         pjoin(components, "bootstrap-tour", "build", "js", "bootstrap-tour.min.js"),
         pjoin(components, "font-awesome", "css", "*.css"),
@@ -144,7 +144,7 @@ def find_package_data():
         pjoin(components, "jquery", "jquery.min.js"),
         pjoin(components, "jquery-typeahead", "dist", "jquery.typeahead.min.js"),
         pjoin(components, "jquery-typeahead", "dist", "jquery.typeahead.min.css"),
-        pjoin(components, "jquery-ui", "ui", "minified", "jquery-ui.min.js"),
+        pjoin(components, "jquery-ui", "jquery-ui.min.js"),
         pjoin(components, "jquery-ui", "themes", "smoothness", "jquery-ui.min.css"),
         pjoin(components, "jquery-ui", "themes", "smoothness", "images", "*"),
         pjoin(components, "marked", "lib", "marked.js"),
@@ -157,8 +157,9 @@ def find_package_data():
         pjoin(components, "underscore", "underscore-min.js"),
         pjoin(components, "moment", "moment.js"),
         pjoin(components, "moment", "min", "*.js"),
-        pjoin(components, "xterm.js", "dist", "xterm.js"),
-        pjoin(components, "xterm.js", "dist", "xterm.css"),
+        pjoin(components, "xterm.js", "index.js"),
+        pjoin(components, "xterm.js-css", "index.css"),
+        pjoin(components, "xterm.js-fit", "index.js"),
         pjoin(components, "text-encoding", "lib", "encoding.js"),
     ])
 
@@ -210,6 +211,7 @@ def find_package_data():
         'notebook.tests' : js_tests,
         'notebook.bundler.tests': ['resources/*', 'resources/*/*', 'resources/*/*/.*'],
         'notebook.services.api': ['api.yaml'],
+        'notebook.i18n': ['*/LC_MESSAGES/*.*'],
     }
     
     return package_data
@@ -335,6 +337,30 @@ def run(cmd, *args, **kwargs):
     kwargs['shell'] = (sys.platform == 'win32')
     return check_call(cmd, *args, **kwargs)
 
+class CompileBackendTranslation(Command):
+    description = "compile the .po files into .mo files, that contain the translations."
+
+    user_options = []
+
+    def initialize_options(self):
+        pass
+
+    def finalize_options(self):
+        pass
+
+
+    def run(self):
+        paths = glob('notebook/i18n/??_??')
+        for p in paths:
+            LANG = p[-5:]
+            for component in ['notebook', 'nbui']:
+                run(['pybabel', 'compile',
+                     '-D', component,
+                     '-f',
+                     '-l', LANG,
+                     '-i', pjoin('notebook', 'i18n', LANG, 'LC_MESSAGES', component+'.po'),
+                     '-o', pjoin('notebook', 'i18n', LANG, 'LC_MESSAGES', component+'.mo')
+                    ])
 
 class Bower(Command):
     description = "fetch static client-side components with bower"
@@ -397,6 +423,28 @@ class Bower(Command):
         update_package_data(self.distribution)
 
 
+def patch_out_bootstrap_bw_print():
+    """Hack! Manually patch out the bootstrap rule that forces printing in B&W.
+
+    We haven't found a way to override this rule with another one.
+    """
+    print_less = pjoin(static, 'components', 'bootstrap', 'less', 'print.less')
+    with open(print_less) as f:
+        lines = f.readlines()
+
+    for ix, line in enumerate(lines):
+        if 'Black prints faster' in line:
+            break
+    else:
+        return  # Already patched out, nothing to do.
+
+    rmed = lines.pop(ix)
+    print("Removed line", ix, "from bootstrap print.less:")
+    print("-", rmed)
+    print()
+    with open(print_less, 'w') as f:
+        f.writelines(lines)
+
 class CompileCSS(Command):
     """Recompile Notebook CSS
     
@@ -423,6 +471,8 @@ class CompileCSS(Command):
         self.run_command('jsdeps')
         env = os.environ.copy()
         env['PATH'] = npm_path
+
+        patch_out_bootstrap_bw_print()
         
         for src, dst in zip(self.sources, self.targets):
             try:
@@ -441,7 +491,7 @@ class CompileCSS(Command):
 
 
 class CompileJS(Command):
-    """Rebuild Notebook Javascript main.min.js files
+    """Rebuild Notebook Javascript main.min.js files and translation files.
     
     Calls require via build-main.js
     """
@@ -489,23 +539,35 @@ class CompileJS(Command):
                 print(source, target)
                 return True
         return False
-        
+
     def build_main(self, name):
         """Build main.min.js"""
         target = pjoin(static, name, 'js', 'main.min.js')
-        
+
         if not self.should_run(name, target):
             log.info("%s up to date" % target)
             return
         log.info("Rebuilding %s" % target)
         run(['node', 'tools/build-main.js', name])
 
+    def build_jstranslation(self, trd):
+        lang = trd[-5:]
+        run([
+            pjoin('node_modules', '.bin', 'po2json'),
+            '-p', '-F',
+            '-f', 'jed1.x',
+            '-d', 'nbjs',
+            pjoin('notebook', 'i18n', lang, 'LC_MESSAGES', 'nbjs.po'),
+            pjoin('notebook', 'i18n', lang, 'LC_MESSAGES', 'nbjs.json'),
+        ])
+
     def run(self):
         self.run_command('jsdeps')
         env = os.environ.copy()
         env['PATH'] = npm_path
         pool = ThreadPool()
         pool.map(self.build_main, self.apps)
+        pool.map(self.build_jstranslation, glob('notebook/i18n/??_??'))
         # update package data in case this created new files
         update_package_data(self.distribution)
 
@@ -560,6 +622,7 @@ def css_js_prerelease(command, strict=False):
             try:
                 self.distribution.run_command('js')
                 self.distribution.run_command('css')
+                self.distribution.run_command('backendtranslations')
             except Exception as e:
                 # refresh missing
                 missing = [ t for t in targets if not os.path.exists(t) ]
