@@ -19,12 +19,13 @@ var rjs_config = {
     jquery: 'components/jquery/jquery.min',
     json: 'components/requirejs-plugins/src/json',
     text: 'components/requirejs-text/text',
-    bootstrap: 'components/bootstrap/js/bootstrap.min',
+    bootstrap: 'components/bootstrap/dist/js/bootstrap.min',
     bootstraptour: 'components/bootstrap-tour/build/js/bootstrap-tour.min',
-    "jquery-ui": 'components/jquery-ui/ui/minified/jquery-ui.min',
+    "jquery-ui": 'components/jquery-ui/jquery-ui.min',
     moment: 'components/moment/min/moment-with-locales',
     codemirror: 'components/codemirror',
-    xterm: 'components/xterm.js/dist/xterm',
+    xterm: 'components/xterm.js/index',
+    'xtermjs-fit': 'components/xterm.js-fit/index',
     typeahead: 'components/jquery-typeahead/dist/jquery.typeahead',
     contents: 'empty:',
     custom: 'empty:',
